@@ -405,12 +405,7 @@ sub buildCyrusGroups
     my $count = 60000;
     if ($mesg->code <= 0) {
         foreach $ldapobject ($mesg->entries) {
-	    my @dcs = split(/,/,$ldapobject->dn());
-	    my @dn;
-	    while( pop( @dcs ) =~ /dc=(.*)/ ) {
-	      push(@dn, $1);
-	    }
-            my $group = $ldapobject->get_value('cn') . '@'.join('.',reverse(@dn)) . ":*:$count:";
+            my $group = lc($ldapobject->get_value('cn')) . '@'.$Kolab::config{'postfix-mydomain'} . ":*:$count:";
             my $userlist = $ldapobject->get_value('member', asref => 1);
             foreach (@$userlist) {
 	      my $uid = $_;
@@ -421,7 +416,7 @@ sub buildCyrusGroups
 		my $mail;
 		($mail = $umesg->entry(0)->get_value('mail')) or
 		($mail = $umesg->entry(0)->get_value('uid'));
-		$group .= $mail.',';		
+		$group .= lc($mail).',';		
 	      }
 	    }
             $group =~ s/,$//;
@@ -566,6 +561,7 @@ my %templates = (
 		 "$templatedir/amavisd.conf.template" => "$prefix/etc/amavisd/amavisd.conf",
 		 "$templatedir/main.cf.template" => "$prefix/etc/postfix/main.cf",
 		 "$templatedir/master.cf.template" => "$prefix/etc/postfix/master.cf",
+		 "$templatedir/kolab_smtpdpolicy.conf.template" => "$prefix/etc/kolab/kolab_smtpdpolicy.conf",
 		 "$templatedir/saslauthd.conf.template" => "$prefix/etc/sasl/saslauthd.conf",
 		 "$templatedir/imapd.conf.template" => "$prefix/etc/imapd/imapd.conf",
 		 "$templatedir/httpd.conf.template" => "$prefix/etc/apache/apache.conf",
@@ -588,6 +584,7 @@ my %permissions = (
 		   "$prefix/etc/resmgr/resmgr.conf"                       => 0640,
 		   "$prefix/etc/postfix/main.cf"                          => 0640,
 		   "$prefix/etc/postfix/master.cf"                        => 0640,
+		   "$prefix/etc/kolab/kolab_smtpdpolicy.conf"             => 0640,
 		   "$prefix/etc/clamav/clamd.conf"                        => 0640,
 		   "$prefix/etc/clamav/freshclam.conf"                    => 0640,
 		   "$prefix/etc/amavisd/amavisd.conf"                     => 0640,
@@ -612,6 +609,7 @@ my %ownership = (
 		 "$prefix/etc/resmgr/resmgr.conf"                       => "kolab:kolab-n",
 		 "$prefix/etc/postfix/main.cf"                          => "kolab:kolab-r",
 		 "$prefix/etc/postfix/master.cf"                        => "kolab:kolab-r",
+		 "$prefix/etc/kolab/kolab_smtpdpolicy.conf"             => "kolab:kolab-n",
 		 "$prefix/etc/clamav/clamd.conf"                        => "kolab:kolab-r",
 		 "$prefix/etc/clamav/freshclam.conf"                    => "kolab:kolab-r",
 		 "$prefix/etc/amavisd/amavisd.conf"                     => "kolab:kolab-r",
