@@ -240,14 +240,15 @@ sub createObject
 
     # No action for groups or external
     return if( $objuidfield eq '' );
-    my $uid = trim($object->get_value($objuidfield)) || 0;
+    my $uid = lc(trim($object->get_value($objuidfield))) || 0;
     return unless $uid;
+    return if( $objuidfield eq 'mail' && !$object->get_value('uid') );
 
     my $kolabhomeserver = lc($object->get_value('kolabhomeserver'));
     my $islocal = 1;
     my $del = $object->get_value($Kolab::config{$p . '_field_deleted'}, asref => 1);
     if( ref($del) eq 'ARRAY' && @$del > 0 ) {
-      Kolab::log('L', "Kolab::LDAP::createObject() skipping object ".$object->get_value($objuidfield)
+      Kolab::log('L', "Kolab::LDAP::createObject() skipping object ".lc($object->get_value($objuidfield))
 		 ." because it is deleted");
       return;
     }
